summaryrefslogtreecommitdiffstats
path: root/src/usr/hwas
diff options
context:
space:
mode:
authorayma <ayma@us.ibm.com>2014-03-04 16:19:49 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2014-03-15 12:25:22 -0500
commit9ef3e1b8cd5d2ee02984478b1882677331da08fa (patch)
tree7cb7804214eedc70826242dadd78c1e117fde854 /src/usr/hwas
parentd05eda21bf62fe34d0dcbdd786794707c5c9f048 (diff)
downloadtalos-hostboot-9ef3e1b8cd5d2ee02984478b1882677331da08fa.tar.gz
talos-hostboot-9ef3e1b8cd5d2ee02984478b1882677331da08fa.zip
change to check all present MBA and MCS in host_prd_hwreconfig
need to change host_prd_hwreconfig to use all present targets instead of only functional targets. This allows the HWP to mask FIRS appropriately Change-Id: I795adf302ff4da5c731d2356433fd775b5f1ba45 CQ: SW245901 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/9297 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/hwas')
-rw-r--r--src/usr/hwas/hostbootIstep.C26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/usr/hwas/hostbootIstep.C b/src/usr/hwas/hostbootIstep.C
index 822a88ce8..34860b3bc 100644
--- a/src/usr/hwas/hostbootIstep.C
+++ b/src/usr/hwas/hostbootIstep.C
@@ -277,16 +277,16 @@ void* host_prd_hwreconfig( void *io_pArgs )
break;
}
- // Lists for functional MCS/Centaurs
- TARGETING::TargetHandleList l_fncMcsList;
- TARGETING::TargetHandleList l_fncCentaurList;
+ // Lists for present MCS/Centaurs
+ TARGETING::TargetHandleList l_presMcsList;
+ TARGETING::TargetHandleList l_presCentaurList;
- // find all functional MCS chiplets of all procs
- getChipletResources(l_fncMcsList, TYPE_MCS, UTIL_FILTER_FUNCTIONAL);
+ // find all present MCS chiplets of all procs
+ getChipletResources(l_presMcsList, TYPE_MCS, UTIL_FILTER_PRESENT);
for (TargetHandleList::const_iterator
- l_mcs_iter = l_fncMcsList.begin();
- l_mcs_iter != l_fncMcsList.end();
+ l_mcs_iter = l_presMcsList.begin();
+ l_mcs_iter != l_presMcsList.end();
++l_mcs_iter)
{
// make a local copy of the MCS target
@@ -295,22 +295,22 @@ void* host_prd_hwreconfig( void *io_pArgs )
TARGETING::ATTR_HUID_type l_currMcsHuid =
TARGETING::get_huid(l_pMcs);
- // Find all the functional Centaurs that are associated with this MCS
- getChildAffinityTargets(l_fncCentaurList, l_pMcs,
- CLASS_CHIP, TYPE_MEMBUF);
+ // Find all the present Centaurs that are associated with this MCS
+ getChildAffinityTargetsByState(l_presCentaurList, l_pMcs,
+ CLASS_CHIP, TYPE_MEMBUF, UTIL_FILTER_PRESENT);
// There will always be 1 Centaur associated with a MCS.
- if(1 != l_fncCentaurList.size())
+ if(1 != l_presCentaurList.size())
{
TRACFCOMP(ISTEPS_TRACE::g_trac_isteps_trace,
- "No functional Centaurs found for "
+ "No present Centaurs found for "
"MCS target HUID %.8X , skipping this MCS",
l_currMcsHuid);
continue;
}
// Make a local copy
- const TARGETING::Target * l_pCentaur = l_fncCentaurList[0];
+ const TARGETING::Target * l_pCentaur = l_presCentaurList[0];
// Retrieve HUID of current Centaur
TARGETING::ATTR_HUID_type l_currCentaurHuid =
TARGETING::get_huid(l_pCentaur);
OpenPOWER on IntegriCloud